# Email verification v0.3.0


## Table of Contents

- [Installation](#installation)
- [Example](#using)
- [Update](#update)

## Installation

**For using module in project use:**

   ```bash
   pip install email-verification==0.3.0
   ```
## Using

   **The example how to use my module you can see in main.py**

## Update

**To update email_verification use:**
```bash
pip install --upgrade email-verification
```
